# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-11-30 15:06
@IDE     : PyCharm
'''
import paramiko


def remote_scp(host_ip, remote_path, local_path, username, password=None):
    t = paramiko.Transport(host_ip)
    t.connect(username=username, password=password)  # 登录远程服务器
    sftp = paramiko.SFTPClient.from_transport(t)  # sftp传输协议
    sftp.get(remote_path, local_path)
    t.close()





# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-11-30 17:31
@IDE     : PyCharm
'''
name = 'Eric-Tools'
__title__ = 'tools'
__description__ = 'Python HTTP for Humans.'
__version__ = "1.1.2.1"
__author__ = 'Eric'
__doc__ = ["Python Daily Development Tools"]
__url__ = "https://github.com/Eric-jxl/Tools"
__license__ = "MIT"

from . import exception_class
from . import resize_image
from . import test
from . import logger,ip
from . import encryption_classmethod
from . import pgsql
from . import sftp



# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-08-07 09:24
'''
import base64
__all__ =['image_resize_image','encode_base64','decode_base64']
__author__ = 'Eric'
__doc__ = "压缩图片 默认像素1024*1024"

try:
    import cStringIO as StringIO
except ImportError:
    try:
        import StringIO
    except ImportError:
        from io import StringIO


from PIL import Image
from PIL import ImageEnhance

def encode_base64(file_path):
    with open(file_path,'rb') as f:
        image_data = f.read()
        base64_data = base64.b64encode(image_data)
        return base64_data
def decode_base64(fname,base64_data):
    with open(fname,'wb') as file:
        decode_data = base64.b64decode(base64_data)  # 解码
        file.write(decode_data)


# source_data = encode_base64('/Users/eric/Documents/photo/2a4100008d310b5fd8a8.jpeg')

def image_resize_image(base64_source, size=(1024, 1024), encoding='base64', filetype=None, avoid_if_small=False):

    if not base64_source:
        return False
    if size == (None, None):
        return base64_source
    image_stream = StringIO.StringIO(base64_source.decode(encoding))
    image = Image.open(image_stream)
    # store filetype here, as Image.new below will lose image.format
    filetype = (filetype or image.format).upper()

    filetype = {
        'BMP': 'PNG',
    }.get(filetype, filetype)

    asked_width, asked_height = size
    if asked_width is None:
        asked_width = int(image.size[0] * (float(asked_height) / image.size[1]))
    if asked_height is None:
        asked_height = int(image.size[1] * (float(asked_width) / image.size[0]))
    size = asked_width, asked_height

    # check image size: do not create a thumbnail if avoiding smaller images
    if avoid_if_small and image.size[0] <= size[0] and image.size[1] <= size[1]:
        return base64_source

    if image.size != size:
        image = image_resize_and_sharpen(image, size)
    if image.mode not in ["1", "L", "P", "RGB", "RGBA"]:
        image = image.convert("RGB")

    background_stream = StringIO.StringIO()
    image.save(background_stream, filetype)
    return background_stream.getvalue().encode(encoding)

def image_resize_and_sharpen(image, size, preserve_aspect_ratio=False, factor=2.0):

    if image.mode != 'RGBA':
        image = image.convert('RGBA')
    image.thumbnail(size, Image.ANTIALIAS)
    if preserve_aspect_ratio:
        size = image.size
    sharpener = ImageEnhance.Sharpness(image)
    resized_image = sharpener.enhance(factor)
    # create a transparent image for background and paste the image on it
    image = Image.new('RGBA', size, (255, 255, 255, 0))
    image.paste(resized_image, ((size[0] - resized_image.size[0]) / 2, (size[1] - resized_image.size[1]) / 2))
    return image

# coding  = image_resize_image(source_data)
# decode_base64('风景.jpg',coding)


# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-09-15 17:20
@IDE     : PyCharm
'''

import requests
try:
    from File.tools.logger import Logger,FucLog
except ImportError:
    from logger import Logger,FucLog

@FucLog.loggerInFile('error.log')
def ip_search(ip=None):
    assert not isinstance(ip,(int,long)),'ip类型不能为数字'
    if ip is not None:
        if isinstance(ip, (list, set)):
            for i in ip:
                url = 'http://ip-api.com/json/' + i + '?lang=zh-CN'
                response = requests.post(url)
                print response.content

        elif isinstance(ip,basestring):
            url = 'http://ip-api.com/json/' + ip + '?lang=zh-CN'
            response = requests.post(url)
            res = response.json()
            print str({u'国家': res['country'], u'省/直辖市': res['regionName'], u'城市': res['city'],
                       u'运营商': res['isp']}).replace('u\'', '\'') \
                .encode('utf-8').decode('unicode_escape')


    else:
        url = 'http://ip-api.com/json/?lang=zh-CN'
        response = requests.post(url)
        print response.content


# ip_search(ip=["34.220.114.243",'114.84.44.228'])


# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-09-10 10:37
@IDE     : PyCharm
'''

import os
import time
import datetime


class RemoveFile(object):
    def __init__(self, filename, timedifference):
        self.filename = filename
        self.timedifference = timedifference

    @staticmethod
    def fileremove(filename, timedifference):
        '''remove file'''

        date = datetime.datetime.fromtimestamp(os.path.getmtime(filename))
        now = datetime.datetime.now()

        if (now - date).seconds > timedifference:
            if os.path.exists(filename):
                os.remove(filename)
                print 'remove file: %s' % filename
            else:
                print 'no such file: %s' % filename


FILE_DIR = '/Users/eric/Documents/rh_gzw_property/'

if __name__ == '__main__':

    print 'Script is running...'

    while True:
        ITEMS = os.listdir(FILE_DIR)
        NEWLIST = []
        for names in ITEMS:
            if names.endswith(".txt"):
                NEWLIST.append(FILE_DIR + names)

        for names in NEWLIST:
            print 'current file: %s' % (names)
            RemoveFile.fileremove(names, 10)

        time.sleep(2)



# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2021-01-27 16:08
@IDE     : PyCharm
'''
import psycopg2


class PostgreSQL(object):
    def __init__(self, database, user, password, host, port=5432):
        self.database = database
        self.user = user
        self.password = password
        self.host = host
        self.port = port

    def __str__(self):
        return '{0},{1},{2}'.format(self.database, self.user, self.host)

    def __repr__(self):
        return "Database:%s User:%s Host:%s" % (self.database, self.user, self.host)

    def __setattr__(self, key, value):
        self.__dict__[key] = value

    def __getattr__(self, item):
        print self.__dict__[item]
        return self.__dict__[item]

    def __call__(self, *args, **kwargs):
        print '%s'% PostgreSQL.__dict__

    @property
    def info(self):
        return psycopg2.__version__,psycopg2.__doc__



    def operate(self, sql, params):
        count = 0
        try:
            self.connect()
            count = self.cursor.execute(sql, params)
            self.conn.commit()
            self.close()
        except Exception, e:
            print e.message
        return count

    def connect(self):
        self.conn = psycopg2.connect(database=self.database, host=self.host, port=self.port, user=self.user,
                                     password=self.password)

        self.cursor = self.conn.cursor()

    def close(self):
        self.cursor.close()
        self.conn.close()

    def get_one(self, sql, params=()):
        result = None
        try:
            self.connect()
            self.cursor.execute(sql, params)
            result = self.cursor.fetchone()
            self.close()
        except Exception, e:
            print e.message
        return result

    def get_all(self, sql, params=()):
        tup = ()
        try:
            self.connect()
            self.cursor.execute(sql, params)
            tup = self.cursor.fetchall()
            self.close()
        except Exception, e:
            print e.message
        return tup

    def insert(self, sql, params=()):
        return self.operate(sql, params)

    def update(self, sql, params=()):
        return self.operate(sql, params)

    def delete(self, sql, params=()):
        return self.operate(sql, params)







# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2021-01-15 13:50
@IDE     : PyCharm
'''

import smtplib
from email.mime.text import MIMEText
from email.utils import formataddr
import sys
reload(sys)
sys.setdefaultencoding("utf-8")

Send_Email = '***@qq.com'  # 发件人邮箱账号
pwd = '*******'  # 发件人邮箱密码
Receive_Email = '****@163.com'


def mail():
    try:
        msg = MIMEText('Test QQ Email', 'plain', 'utf-8')
        msg['From'] = formataddr(["***", Send_Email])  # 括号里的对应发件人邮箱昵称、发件人邮箱账号
        msg['To'] = formataddr(["***", Receive_Email])  # 括号里的对应收件人邮箱昵称、收件人邮箱账号
        msg['Subject'] = str("发送邮件测试").decode('utf-8') # 邮件的主题，也可以说是标题

        server = smtplib.SMTP_SSL("smtp.qq.com", 4655)  # 发件人邮箱中的SMTP服务器，端口是25
        server.login(Send_Email, pwd)
        server.sendmail(Send_Email, [Receive_Email, ], msg.as_string())  # 括号中对应的是发件人邮箱账号、收件人邮箱账号、发送邮件
        server.quit()  # 关闭连接
    except Exception as e:
        print '发送邮件失败:%s' % e
        return e


mail()


# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-12-02 11:01
@IDE     : PyCharm
'''

# import os, base64
# print os.path.abspath(os.path.join(os.getcwd()))
# os.chdir(r'/Users/eric/Documents/File/tools')
# with open ('s.jpg', 'rb') as icon:
#     iconData = icon.read()
# iconData = base64.b64encode(iconData)
# print iconData
# LIMIT = 60
# liIcon = []
# while True:
#     sLimit = iconData[:LIMIT]
#     iconData = iconData[LIMIT:]
#     liIcon.append('\'%s\'' % sLimit)
#     if len(sLimit) < LIMIT:
#         break
# print os.linesep.join(liIcon)

# from apscheduler.schedulers.blocking import BlockingScheduler
# from datetime import datetime
# # 输出时间
# def job():
#     print(datetime.now().strftime("%Y-%m-%d %H:%M:%S"))
# # BlockingScheduler
# scheduler = BlockingScheduler()
# scheduler.add_job(job, 'cron', day_of_week='1-5', hour=18, minute=00)
# # scheduler.add_job(job, 'interval', seconds=3,id='job_id')
# scheduler.start()
# scheduler.shutdown(wait=False)

# fixme：预算预删除代码

# @api.multi
# def do_submit(self, need_check=True):
#     # TODO:费用提交检查分析账户的余额/
#     if not self.expense_line_ids:
#         raise UserError(_(u'请输入报销内容！'))
#
#     if self.expense_line_ids:
#
#         total = 0.0
#         balance = 0.0
#         txt = ''
#         for r in self.expense_line_ids.mapped('analytic_account_id'):
#             budget_analytic = self.env['crossovered.budget.lines'].search([('analytic_account_id', '=', r.id)])
#             for val in budget_analytic:
#                 budget_name = val.analytic_account_id.name
#                 date_from = min(budget_analytic.mapped('date_from'))
#                 date_to = max(budget_analytic.mapped('date_to'))
#                 val.sudo()._compute_practical_amount()
#                 new_balance = self.env['crossovered.budget.lines'].search(
#                     [('analytic_account_id', '=', val.analytic_account_id.id),
#                      ('date_from', '>=', date_from), ('date_to', '<=', date_to)])
#                 # 执行计算等函数
#                 # for crossovered in new_balance:
#                 #     crossovered._compute_practical_amount()
#                 #     crossovered._compute_balance()
#
#                 balance = min([-i for i in new_balance.mapped('new_balance')])
#
#                 total = sum(self.expense_line_ids.filtered(lambda x: x.analytic_account_id.name == budget_name)
#                             .mapped('unit_amount'))
#
#             for i in range(len(budget_analytic) / 2):
#                 txt += '%s分析账户' % (budget_name)
#         if need_check and total > balance:
#             strings = str(txt) + '现已超预算，是否继续提交或审批?'
#             return self.jump_to_wizard('do_submit', strings)
#         else:
#             super(HrExpenseSheet, self).do_submit()

# @api.multi
# def do_approved(self, need_check=True):
#     # fixme 审批检查分析账户余额
#     expense_ids = self.expense_line_ids
#     if expense_ids:
#         account_list = expense_ids.mapped('analytic_account_id')
#         total = 0.0
#         balance = 0.0
#         txt = ''
#         for r in account_list:
#             budget_analytic = self.env['crossovered.budget.lines'].search([('analytic_account_id', '=', r.id)])
#             for val in budget_analytic:
#                 budget_name = val.analytic_account_id.name
#                 date_from = min(budget_analytic.mapped('date_from'))
#                 date_to = max(budget_analytic.mapped('date_to'))
#
#                 val.sudo()._compute_practical_amount()
#                 # val.commit()
#                 new_balance = self.env['crossovered.budget.lines'].search(
#                     [('analytic_account_id', '=', val.analytic_account_id.id),
#                      ('date_from', '>=', date_from), ('date_to', '<=', date_to)])
#
#                 balance = min([-i for i in new_balance.mapped('new_balance')])
#                 total = sum(expense_ids.filtered(lambda x: x.analytic_account_id.name == budget_name)
#                             .mapped('unit_amount'))
#             for i in range(len(budget_analytic) / 2):
#                 txt += '%s分析账户' % (budget_name)
#         if need_check and total > balance:
#             strings = str(txt) + '现已超预算，是否继续提交或审批?'
#             return self.jump_to_wizard('do_approved', strings)
#         else:
#             super(HrExpenseSheet, self).do_approved()



# -*- coding:utf-8 -*-
'''
@Author  : Eric
@Time    : 2020-11-30 11:09
@IDE     : PyCharm
'''
import logging
import traceback
from logging import handlers
from logging.handlers import TimedRotatingFileHandler


class Logger(object):
    level_relations = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'crit': logging.CRITICAL
    }  # 日志级别关系映射

    def __init__(self, filename, level='info', when='D', backCount=3,
                 fmt='%(asctime)s - %(pathname)s[line:%(lineno)d-%(funcName)s] - %(levelname)s: %(message)s'):
        self.logger = logging.getLogger(filename)
        format_str = logging.Formatter(fmt)  # 设置日志格式
        self.logger.setLevel(self.level_relations.get(level))  # 设置日志级别
        sh = logging.StreamHandler()  # 往屏幕上输出
        sh.setFormatter(format_str)  # 设置屏幕上显示的格式
        th = handlers.TimedRotatingFileHandler(filename=filename, when=when, backupCount=backCount,
                                               encoding='utf-8')  # 往文件里写入#指定间隔时间自动生成文件的处理器
        # 实例化TimedRotatingFileHandler
        # interval是时间间隔，backupCount是备份文件的个数，如果超过这个个数，就会自动删除，when是间隔的时间单位，单位有以下几种：
        # S 秒 M 分 H 小时、D 天、
        # W 每星期（interval==0时代表星期一）
        # midnight 每天凌晨
        th.setFormatter(format_str)  # 设置文件里写入的格式
        self.logger.addHandler(sh)  # 把对象加到logger里
        self.logger.addHandler(th)


class FucLog(object):
    @staticmethod
    def loggerInFile(filename):  # 带参数的装饰器需要2层装饰器实现,第一层传参数，第二层传函数，每层函数在上一层返回
        def decorator(func):
            def inner(*args, **kwargs):  # 1
                logger = logging.getLogger(filename)
                logger.setLevel(logging.INFO)
                handler = TimedRotatingFileHandler(filename,
                                                   when="d",
                                                   interval=1,
                                                   backupCount=5)
                formatter = logging.Formatter(
                    '%(asctime)s - %(pathname)s[line:%(lineno)d-%(funcName)s] - %(levelname)s: %(message)s')
                console =logging.StreamHandler()
                console.setLevel(logging.INFO)
                console.setFormatter(formatter)
                handler.setFormatter(formatter)
                logger.addHandler(handler)
                logger.addHandler(console)
                try:
                    result = func(*args, **kwargs)  # 2
                    logger.info(result)
                except:
                    logger.error(traceback.format_exc())

            return inner
        return decorator



# -*- coding:utf-8 -*-

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Eric-Tools",
    version="1.1.2.1",
    author="Eric",
    author_email="799050481@qq.com",
    description="Python Daily Development Tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Eric-jxl/Tools",
    packages=setuptools.find_packages(),
    license="MIT License",
    keyword = ["eric","tools"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.7.16',
    install_requires = [
        'psycopg2',
        'requests',
        'paramiko',
        'Pillow',
    ]
)
